@@ -20,7 +20,7 @@ sub normalize_maketext_string {
 
     # 2. look for multi's
     if ( ${$string_sr} =~ s/(?:[.]{2,}|[,]{2,})/…/g ) {
-        $filter->add_violation('multiple period/comma instead of ellipsis character');
+        $filter->add_warning('multiple period/comma instead of ellipsis character');
     }
 
     # 3. restore placeholder
@@ -32,37 +32,37 @@ sub normalize_maketext_string {
     # }
 
     if ( ${$string_sr} =~ s/^(|\xc2\xa0|\[output\,nbsp\])…/ …/ ) {
-        $filter->add_violation('initial ellipsis needs to be preceded by a normal space');
+        $filter->add_warning('initial ellipsis should be preceded by a normal space');
     }
 
     # 1. placeholders for legit ones
     my %l;
     my $copy = ${$string_sr};
-    if ( ${$string_sr} =~ s/(\x20|\xc2\xa0|\[output\,nbsp\])…$/ELLIPSIS_END/ ) {    # final
+    if ( ${$string_sr} =~ s/((?:\x20|\xc2\xa0|\[output\,nbsp\])…[\!\?\.\:])$/ELLIPSIS_END/ ) {    # final
         $l{'ELLIPSIS_END'} = $1;
     }
 
-    if ( ${$string_sr} =~ s/^ …(\x20|\xc2\xa0|\[output\,nbsp\])/ELLIPSIS_START/ ) {    # initial
+    if ( ${$string_sr} =~ s/^( …(?:\x20|\xc2\xa0|\[output\,nbsp\]))/ELLIPSIS_START/ ) {           # initial
         $l{'ELLIPSIS_START'} = $1;
     }
 
-    while ( ${$string_sr} =~ m/(\x20|\xc2\xa0|\[output\,nbsp\])…(\x20|\xc2\xa0|\[output\,nbsp\])/g ) {
-        ${$string_sr} =~ s/(\x20|\xc2\xa0|\[output\,nbsp\])…(\x20|\xc2\xa0|\[output\,nbsp\])/ELLIPSIS_MEDIAL/;
+    while ( ${$string_sr} =~ m/(\(|\x20|\xc2\xa0|\[output\,nbsp\])…(\)|\x20|\xc2\xa0|\[output\,nbsp\])/g ) {
+        ${$string_sr} =~ s/(\(|\x20|\xc2\xa0|\[output\,nbsp\])…(\)|\x20|\xc2\xa0|\[output\,nbsp\])/ELLIPSIS_MEDIAL/;
         push @{ $l{'ELLIPSIS_MEDIAL'} }, [ $1, $2 ];
     }
 
     # 2. mark any remaining ones (that are not legit)
     if ( ${$string_sr} =~ s/\A …(?!\x20|\xc2\xa0|\[output\,nbsp\])/ … / ) {
-        $filter->add_violation('initial ellipsis needs to be followed by a normal space or a non-break-space in bracket notation or character form');
+        $filter->add_warning('initial ellipsis should be followed by a normal space or a non-break-space (in bracket notation or character form)');
     }
 
     if ( ${$string_sr} =~ s/…(?:\x20|\xc2\xa0|\[output\,nbsp\]|\s)+\z/…/ ) {
-        $filter->add_violation('final ellipsis should not be followed by anything');
+        $filter->add_warning('final ellipsis should be followed by a valid punctuation mark or nothing');
     }
 
     if ( ${$string_sr} =~ m/…\z/ && ${$string_sr} !~ m/(?:\x20|\xc2\xa0|\[output\,nbsp\])…\z/ ) {
         ${$string_sr} =~ s/…$/ …/;
-        $filter->add_violation('final ellipsis needs to be preceded by a normal space or a non-break-space in bracket notation or character form');
+        $filter->add_warning('final ellipsis should be preceded by a normal space or a non-break-space (in bracket notation or character form)');
     }
 
     my $medial_prob = 0;
@@ -75,12 +75,12 @@ sub normalize_maketext_string {
     }
 
     if ($medial_prob) {
-        $filter->add_violation('medial ellipsis should be surrounded on each side by a normal space or a non-break-space in bracket notation or character form');
+        $filter->add_warning('medial ellipsis should be surrounded on each side by a parenthesis or normal space or a non-break-space (in bracket notation or character form)');
     }
 
     # 3. reconstruct the valid ones
-    ${$string_sr} =~ s/ELLIPSIS_END/$l{'ELLIPSIS_END'}…/      if exists $l{'ELLIPSIS_END'};
-    ${$string_sr} =~ s/ELLIPSIS_START/ …$l{'ELLIPSIS_START'}/ if exists $l{'ELLIPSIS_START'};
+    ${$string_sr} =~ s/ELLIPSIS_END/$l{'ELLIPSIS_END'}/     if exists $l{'ELLIPSIS_END'};
+    ${$string_sr} =~ s/ELLIPSIS_START/$l{'ELLIPSIS_START'}/ if exists $l{'ELLIPSIS_START'};
     if ( exists $l{'ELLIPSIS_MEDIAL'} ) {
         for my $medial ( @{ $l{'ELLIPSIS_MEDIAL'} } ) {
             ${$string_sr} =~ s/ELLIPSIS_MEDIAL/$medial->[0]…$medial->[1]/;
@@ -108,13 +108,13 @@ __END__
 
 =back
 
-Valid whitespace is a normal space or a non-break-space (literal (OSX: ⌥space) or via [output,nbsp]). 
+Valid whitespace is a normal space or a non-break-space (literal (OSX: ⌥space) or via [output,nbsp]).
 
 The only exception is that the initial space has to be a normal space (non-break-space there would imply formatting or partial phrase, ick).
 
 =head2 Rationale
 
-We want to be simple, consistent, and clear. 
+We want to be simple, consistent, and clear.
 
 =over 4
 
@@ -123,7 +123,7 @@ We want to be simple, consistent, and clear.
   initial:…{0}
   medial:{0}…{1}
   final:{0}…
-  
+
 Yet, English provides many more rules based on location in the text, purpose (show an omission, indicate a trailing off for various purposes), context (puntuation before or after?), and author’s whim.
 
 Some are exact opposites and yet still valid either way.
@@ -159,11 +159,15 @@ So lets keep it clear.
 Tip: If you’re doing a single word(e.g. to indicate an action is happening) you might consider doing a non-break-space to the left of it:
 
     'Loading …' # i.e. Loading(OSX: ⌥-space)…
-    
+
     'Loading[output,nbsp]…' # visually explicit
 
 =head1 possible violations
 
+None
+
+=head1 possible warnings
+
 =over 4
 
 =item multiple period/comma instead of ellipsis character
@@ -172,28 +176,24 @@ We want an ellipsis character instead of 3 periods (or 2 periods, 4 or 5 periods
 
 These will be turned into an ellipsis character.
 
-=item initial ellipsis needs to be preceded by a normal space
+=item initial ellipsis should be preceded by a normal space
 
 The string is modified with a corrected version.
 
-=item initial ellipsis needs to be followed by a normal space or a non-break-space in bracket notation or character form
+=item initial ellipsis should be followed by a normal space or a non-break-space (in bracket notation or character form)
 
 The string is modified with a corrected version.
 
-=item final ellipsis needs to be preceded by a normal space or a non-break-space in bracket notation or character form
+=item final ellipsis should be preceded by a normal space or a non-break-space (in bracket notation or character form)
 
 The string is modified with a corrected version.
 
-=item final ellipsis should not be followed by anything
+=item final ellipsis should be followed by a valid punctuation mark or nothing
 
 The string is modified with a corrected version.
 
-=item medial ellipsis should be surrounded on each side by a normal space or a non-break-space in bracket notation or character form
+=item medial ellipsis should be surrounded on each side by a parenthesis or normal space or a non-break-space (in bracket notation or character form)
 
 The string is modified with a corrected version.
 
-=back 
-
-=head1 possible warnings
-
-None
+=back
