@@ -6,8 +6,6 @@ use warnings;
 sub normalize_maketext_string {
     my ($filter) = @_;
 
-    return $filter->return_value_noop() if !$filter->run_extra_filters();
-
     my $string_sr = $filter->get_string_sr();
 
     # This will handle previously altered characters like " in  the aggregate results
@@ -34,9 +32,23 @@ Detect escaped character sequences.
 
 =head2 Rationale
 
-An escaped character adds ambiguity and is an indication of in-string-formatting (e.g. \n), 
-use of interpolation (which makes for hard to translate strings, could make key lookup erroneously fail, etc), 
-or use of a markup character (e.g. "You are \"awesome\".") which should be done differently (e.g. since that is will break the syntax if used in an HTML tag title attribute).
+An escaped character:
+
+=over 4
+
+=item * adds ambiguity
+
+=item * is an indication of in-string-formatting (e.g. \n)
+
+=item * relies on interpolation
+
+The additional layer of complexity could hinder translators and thus makes room for lower quality translations.
+
+Also, among other things, it could make key lookup erroneously fail.
+
+=item * Indicates use of a markup character (e.g. "You are \"awesome\".") which should be done differently (e.g. since that is will break the syntax if used in an HTML tag title attribute).
+
+=back
 
 =head1 possible violations
 
@@ -48,12 +60,8 @@ If you get false positives then that only goes to help highlight how ambiguity a
 
 A sequence of \n will be replaced w/ [comment,escaped sequence “n”], \" [comment,escaped sequence “"”], etc
 
-=back 
+=back
 
 =head1 possible warnings
 
 None
-
-=head1 Entire filter only runs under extra filter mode.
-
-See L<Locale::Maketext::Utils::Phrase::Norm/extra filters> for more details.
